%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

%{!?ruby_sitelib: %global ruby_sitelib %(/usr/bin/ruby -rrbconfig  -e 'puts Config::CONFIG["sitelibdir"] ')}
%{!?ruby_sitearch: %global ruby_sitearch %(/usr/bin/ruby -rrbconfig -e 'puts Config::CONFIG["sitearchdir"] ')}

# NOTE: no more than one of these flags should be set at the same time!
# RHEL-6 builds (the default) should have all these flags set to 0.
%global fedora              0
%global rhel_5              0

# LIBRARY VERSIONS
# Update these lib numbers in accordance with library numbering policy
# and best practices.
# http://www.gnu.org/software/libtool/manual/libtool.html#Versioning
#
# Fromat: current[:revision[:age]]
#
# current:  The most recent interface number that this library
#           implements.
# revision: The implementation number of the current interface.
# age:      The difference between the newest and oldest interfaces that
#           this library implements.  In other words, the library
#           implements all the interface numbers in the range from
#           number current - age to current.
#
#  1. Start with version information of ‘0:0:0’ for each libtool
#     library.
#  2. Update the version information only immediately before a public
#     release of your software.  More frequent updates are
#     unnecessary, and only guarantee that the current interface
#     number gets larger faster.
#  3. If the library source code has changed at all since the last
#     update, then increment revision (‘c:r:a’ becomes ‘c:r+1:a’).
#  4. If any interfaces have been added, removed, or changed since the
#     last update, increment current, and set revision to 0.
#  5. If any interfaces have been added since the last public release,
#     then increment age.
#  6. If any interfaces have been removed or changed since the last
#     public release, then set age to 0.
#  
# Update qpid/cpp/src/versions.cmake file to change library version (when using cmake)
#
# Note that qpidtypes and qpidmessaging are the libraries which contain
# our official public interfaces and we try not to change.
# The others have no guarantee, which is why we rev them with every release.
# ===========

Name:          qpid-qmf
Version:       0.22
Release:       39%{?dist}
Summary:       The Qpid Management Framework
Group:         System Environment/Libraries
License:       ASL 2.0
URL:           http://qpid.apache.org
Source0:       qpid-%{version}.tar.gz
Patch0:        mrg.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if %{rhel_5}
ExclusiveArch: i386 x86_64
%endif

BuildRequires: cmake
BuildRequires: boost-devel
BuildRequires: libtool
BuildRequires: pkgconfig
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: python-devel
BuildRequires: swig
BuildRequires: nss-devel
BuildRequires: nspr-devel

%if %{rhel_5}
BuildRequires: e2fsprogs-devel
%else
BuildRequires: boost-program-options
BuildRequires: boost-filesystem
BuildRequires: libuuid-devel
%endif


# === Package: qpid-qmf ===

Requires:      qpid-cpp-client = %{version}
#Provides:      qmf = %{version}-%{release}
#Obsoletes:     qmf < %{version}-%{release}

%description
An extensible management framework layered on Qpid messaging

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_libdir}/libqmf2.so.*

# === Package: qpid-qmf-devel ===
%package devel
Summary:       Header files and tools for developing QMF extensions
Group:         Development/System
Requires:      qpid-qmf = %{version}-%{release}
Requires:      qpid-cpp-client-devel = %{version}
#Provides:      qmf-devel = %{version}-%{release}
#Obsoletes:     qmf-devel < %{version}-%{release}

%description devel
Header files and code-generation tools needed for developers of QMF-managed
components.

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%{_libdir}/libqmf2.so
%{_bindir}/qmf-gen
%{python_sitelib}/qmfgen
%{_includedir}/qmf

# === Package: python-qpid-qmf ===
%package -n python-qpid-qmf
Summary:       Python QMF library for Apache Qpid
Group:         Development/Python
Requires:      qpid-qmf = %{version}-%{release}
Requires:      qpid-cpp-client = %{version}
Requires:      python-qpid = %{version}
#Provides:      python-qmf = %{version}-%{release}
#Obsoletes:     python-qmf < %{version}-%{release}
Obsoletes:     python-qmf

%description -n python-qpid-qmf
Python QMF library for Apache Qpid

%files -n python-qpid-qmf
%defattr(-,root,root,-)
%{python_sitearch}/qmf
%{python_sitearch}/cqpid.py*
%{python_sitearch}/_cqpid.so
%{python_sitearch}/qmf2.py*
%{python_sitearch}/cqmf2.py*
%{python_sitearch}/_cqmf2.so
%exclude %{python_sitearch}/mllib
%exclude %{python_sitearch}/qpid

# === Package: ruby-qpid-qmf ===

%ifnarch s390 s390x ppc ppc64

%package -n ruby-qpid-qmf
Summary:       The QPID Management Framework bindings for ruby
Group:         System Environment/Libraries
Requires:      ruby-libs
Requires:      qpid-cpp-client = %{version}
Requires:      qpid-qmf = %{version}-%{release}
#Provides:      ruby-qmf = %{version}-%{release}
#Obsoletes:     ruby-qmf < %{version}-%{release}

%description -n ruby-qpid-qmf
An extensible managememt framework layered on QPID messaging, bindings
for ruby.

%post -n ruby-qpid-qmf -p /sbin/ldconfig

%postun -n ruby-qpid-qmf -p /sbin/ldconfig

%files -n ruby-qpid-qmf
%defattr(-,root,root,-)
%{ruby_sitearch}/cqpid.so
%{ruby_sitearch}/cqmf2.so

%endif

# ===

%prep
%setup -q -n qpid-%{version}
%patch0 -p2

%build
(
    cd cpp
    %cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_EXE_LINKER_FLAGS="-Wl,-z,relro,-z,now" -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-z,relro" -DCMAKE_MODULE_LINKER_FLAGS="-Wl,-z,relro"
    make %{?_smp_mflags}
)

(cd python; %{__python} setup.py build)
(cd extras/qmf; %{__python} setup.py build)

%install
rm -rf %{buildroot}

(cd cpp; make install DESTDIR=%{buildroot})
(cd python; %{__python} setup.py install --skip-build --root %{buildroot} --install-purelib %{python_sitearch})
(cd extras/qmf; %{__python} setup.py install --skip-build --root %{buildroot} --install-purelib %{python_sitearch})

# BZ1004840: set executable flag for libraries to ensure DWARF data is removed
chmod +x %{buildroot}%{python_sitearch}/*.so*
chmod +x %{buildroot}%{ruby_sitearch}/*.so*

shopt -s extglob

rm -fr %{buildroot}%{_libdir}/!(libqmf*|ruby|python*)
rm -fr %{buildroot}%{_localstatedir}
rm -fr %{buildroot}%{_mandir}
rm -fr %{buildroot}%{_bindir}/!(qmf*)
rm -fr %{buildroot}%{_includedir}/qpid/!(agent|console)
rm -fr %{buildroot}%{_libexecdir}
rm -fr %{buildroot}%{_sbindir}
rm -fr %{buildroot}%{_sysconfdir}
rm -fr %{buildroot}%{_datadir}
rm -fr %{buildroot}%{python_sitelib}/qpid*.egg-info
rm -fr %{buildroot}%{python_sitearch}/qpid*.egg-info

%clean
rm -rf %{buildroot}

%changelog
* Fri Aug 29 2014 Irina Boverman <iboverma@redhat.com> - 0.22-39
- Make it consistent with qpid-cpp 0.22-48

* Fri Aug 22 2014 Irina Boverman <iboverma@redhat.com> - 0.22-38
- Make it consistent with qpid-cpp 0.22-47

* Fri Aug  8 2014 Irina Boverman <iboverma@redhat.com> - 0.22-37
- Make it consistent with qpid-cpp 0.22-46

* Fri Aug  1 2014 Irina Boverman <iboverma@redhat.com> - 0.22-36
- Make it consistent with qpid-cpp 0.22-45

* Tue Jul 22 2014 Irina Boverman <iboverma@redhat.com> - 0.22-35
- Make it consistent with qpid-cpp 0.22-44

* Mon Jul 14 2014 Irina Boverman <iboverma@redhat.com> - 0.22-34
- Make it consistent with qpid-cpp 0.22-43

* Fri Jun  6 2014 Irina Boverman <iboverma@redhat.com> - 0.22-33
- Make it consistent with qpid-cpp 0.22-42

* Tue May 27 2014 Irina Boverman <iboverma@redhat.com> - 0.22-32
- Make it consistent with qpid-cpp 0.22-41

* Fri May 16 2014 Irina Boverman <iboverma@redhat.com> - 0.22-31
- Make it consistent with qpid-cpp 0.22-39

* Fri Apr 25 2014 Irina Boverman <iboverma@redhat.com> - 0.22-30
- Make it consistent with qpid-cpp 0.22-38

* Fri Apr  4 2014 Irina Boverman <iboverma@redhat.com> - 0.22-29
- Make it consistent with qpid-cpp 0.22-37

* Fri Mar  7 2014 Irina Boverman <iboverma@redhat.com> - 0.22-28
- Make it consistent with qpid-cpp 0.22-36

* Fri Feb  7 2014 Irina Boverman <iboverma@redhat.com> - 0.22-27
- Make it consistent with qpid-cpp 0.22-34

* Wed Jan 15 2014 Irina Boverman <iboverma@redhat.com> - 0.22-26
- Make it consistent with qpid-cpp 0.22-32

* Fri Jan  3 2014 Irina Boverman <iboverma@redhat.com> - 0.22-25
- Make it consistent with qpid-cpp 0.22-30

* Wed Nov 27 2013 Irina Boverman <iboverma@redhat.com> - 0.22-23
- Removed qmf2.rb file

* Fri Nov 22 2013 Irina Boverman <iboverma@redhat.com> - 0.22-23
- Make it consistent with qpid-cpp 0.22-27

* Fri Nov 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-23
- Added -DCMAKE_MODULE_LINKER_FLAGS=-Wl,-z,relro to cmake
- Resolved bz: 1023637

* Wed Nov  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-22
- Resolves: 1023637
- Make it consistent with qpid-cpp 0.22-25

* Fri Oct 24 2013 Irina Boverman <iboverma@redhat.com> - 0.22-20
- Make it consistent with qpid-cpp 0.22-23

* Thu Oct 24 2013 Irina Boverman <iboverma@redhat.com> - 0.22-19
- Make it consistent with qpid-cpp 0.22-22

* Mon Oct 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-18
- Obsoleted python-qmf
- Make it consistent with qpid-cpp 0.22-21

* Fri Oct 18 2013 Irina Boverman <iboverma@redhat.com> - 0.22-16
- Delete debug data from language binding libraries.
- Resolves: 1004840

* Fri Oct 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-15
- Make it consistent with qpid-cpp 0.22-19

* Thu Sep 26 2013 Irina Boverman <iboverma@redhat.com> - 0.22-14
- Make it consistent with qpid-cpp 0.22-17

* Fri Sep 20 2013 Irina Boverman <iboverma@redhat.com> - 0.22-13
- Make it consistent with qpid-cpp 0.22-16

* Fri Sep 13 2013 Irina Boverman <iboverma@redhat.com> - 0.22-11
- Make it consistent with qpid-cpp 0.22-14
- Removed old client APIs

* Fri Aug 30 2013 Irina Boverman <iboverma@redhat.com> - 0.22-10
- Make it consistent with qpid-cpp 0.22-12

* Thu Aug 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-9
- Make it consistent with qpid-cpp 0.22-11

* Fri Aug  9 2013 Irina Boverman <iboverma@redhat.com> - 0.22-8
- Make it consistent with qpid-cpp 0.22-10

* Thu Jul 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-7
- Make it consistent with qpid-cpp 0.22-8

* Thu Jul 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-6
- Make it consistent with qpid-cpp 0.22-7

* Fri Jun 28 2013 Irina Boverman <iboverma@redhat.com> - 0.22-5
- Resolved bz: 913415

* Fri Jun 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-4
- Make it consistent with qpid-cpp 0.22-5 

* Wed Jun 12 2013 Irina Boverman <iboverma@redhat.com> - 0.22-3
- Updated source with 0.22 tarball  

* Mon May  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-2
- Resolved problem with shared libraries version numbers

* Wed Apr 24 2013 Irina Boverman <iboverma@redhat.com> - 0.22-1
- Rebased to 0.22

* Wed Feb 13 2013 Irina Boverman <iboverma@redhat.com> - 0.18-15
- Resolves: rhbz895535

* Thu Jan 24 2013 Irina Boverman <iboverma@redhat.com> - 0.18-14
- Make it consistent with qpid-cpp 0.18-14

* Wed Dec 12 2012 Irina Boverman <iboverma@redhat.com> - 0.18-13
- Make it consistent with qpid-cpp 0.18-13

* Tue Dec  4 2012 Irina Boverman <iboverma@redhat.com> - 0.18-12
- Resolves: rhbz877553, Make it consistent with qpid-cpp 0.18-12

* Wed Nov 21 2012 Mike Cressman <mcressman@redhat.com> - 0.18-10
- Rebuild for qpid-cpp 0.18-11

* Wed Nov 21 2012 Mike Cressman <mcressman@redhat.com> - 0.18-9
- Rebuild to really make it consistent with qpid-cpp 0.18-10

* Tue Nov 20 2012 Irina Boverman <iboverma@redhat.com> - 0.18-8
- Make it consistent with qpid-cpp 0.18-10

* Tue Nov 13 2012 Irina Boverman <iboverma@redhat.com> - 0.18-7
- Resolves: rhbz876136, make it consistent with qpid-cpp 0.18-9 

* Wed Nov  7 2012 Irina Boverman <iboverma@redhat.com> - 0.18-6
- Make it consistent with qpid-cpp 0.18-7

* Fri Nov  2 2012 Irina Boverman <iboverma@redhat.com> - 0.18-5
- Changed QMF version numbers

* Thu Nov  1 2012 Irina Boverman <iboverma@redhat.com> - 0.18-4
- Make it consistent with latest qpid-cpp 

* Wed Oct 24 2012 Irina Boverman <iboverma@redhat.com> - 0.18-3
- Make is consistent with qpid-cpp 0.18-3

* Sun Oct 14 2012 Irina Boverman <iboverma@redhat.com> - 0.18-2
- Resolves: rhbz#845356, Rebase to 0.18+, 0.18-1
- Make it consistent with qpid-cpp 0.18-2

* Thu Aug 16 2012 Justin Ross <jross@redhat.com> - 0.14-14
- BZs: 693845, 773700, 806869, 847331
* Fri Mar 16 2012 Nuno Santos <nsantos@redhat.com> - 0.14-6
- rhbz#801358
* Thu Mar 15 2012 Nuno Santos <nsantos@redhat.com> - 0.14-5
- rhbz#745600
* Fri Feb 10 2012 Nuno Santos <nsantos@redhat.com> - 0.14-4
- rhbz#765856
* Thu Dec  8 2011 Nuno Santos <nsantos@redhat.com> - 0.14-2
- Fixed install paths
* Tue Nov 29 2011 Justin Ross <jross@redhat.com> - 0.14-1
- Rebase to 0.14
- rhbz#743657 - The pure-python QMF console unnecessarily retains
  references to query results
- rhbz#699499 - [RFE] qmfv2 must provide mainloop integration
- rhbz#681680 - QMF agents wake up several times a second
- rhbz#663461 - Enable new architectures
- Remove python-qpid-qmf and ruby-qpid-qmf from ppc and s390 architectures
* Mon Oct 31 2011 Justin Ross <jross@redhat.com> - 0.10-11
- BZs 743657, 748738 - Prevent memory leak in python console
* Mon May 27 2011 Ted Ross <tross@redhat.com> - 0.10-10
- BZ 709343 - Packaging problem in qpid-qmf-devel (qmf-gen templates)
* Mon May 24 2011 Ted Ross <tross@redhat.com> - 0.10-9
- BZ 707023 - Fix rpmdiff errors
* Mon May  2 2011 Ted Ross <tross@redhat.com> - 0.10-7
- BZ 689907 - Fix rpmdiff errors
* Wed Apr 20 2011 Justin Ross <jross@redhat.com> - 0.10-6
- BZ 694416 - missing dependency of python-qpid-qmf
* Wed Mar 30 2011 Nuno Santos <nsantos@redhat.com> - 0.10-3
- BZ691812
* Tue Mar 22 2011 Nuno Santos <nsantos@redhat.com> - 0.10-1
- Initial version of consolidated, renamed qpid-qmf packages
